/***********************************************************
 * $Id: fancysax.h 1078 2013-12-29 19:02:51Z fancylibs $
 *
 * FancySAX
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSAX_H
#define FANCYSAX_H

#ifdef WIN32
# ifdef __GNUC__
#  ifdef BUILD_fancysax3_DLL
#   define FANCYSAX_API __attribute__((dllexport))
#  else
#   define FANCYSAX_API __attribute__((dllimport))
#  endif
# else
#  ifdef BUILD_fancysax3_DLL
#   define FANCYSAX_API __declspec(dllexport)
#  else
#   define FANCYSAX_API __declspec(dllimport)
#  endif
# endif
#else
# ifdef __GNUC__
#  define FANCYSAX_INTERNAL_API __attribute__((visibility("hidden")))
# endif
#endif

#ifndef FANCYSAX_INTERNAL_API
#define FANCYSAX_INTERNAL_API
#endif

#ifndef FANCYSAX_API
#define FANCYSAX_API
#endif

namespace Fancy {
namespace SAX {

/**
 * A SAX Attribute as reported by @c ContentHandler::startElementNs().
 */
struct FANCYSAX_API Attribute {

    const char *localname; //! The name of the attribute without namespace prefix
    const char *prefix;    //! The namespace prefix of the attribute.
    const char *URI;       //! The namespace URI of the attribute.
    const char *value;     //! The value of the attribute. The value is not null terminated,
    const char *end;       //! The end of the value of the attribute in memory.

    /**
     * @return The length of value in memory, aka @c end-value.
     */
    int valueLength() const { return this->end-this->value; }
};

}}

#endif
