/***********************************************************
 * $Id: fancysaxdtdhandler.h 996 2013-10-07 15:11:39Z fancylibs $
 *
 * FancySAX
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSAXDTDHANDLER_H_
#define FANCYSAXDTDHANDLER_H_

#include <fancyobject.h>
#include <fancysax.h>

namespace Fancy {

namespace SAX {

/**
 * A minimal callback interface for DTD events. FOr parsing ordinary documents
 * you most likely do not need to implement this interface.
 */
class FANCYSAX_API DTDHandler: public virtual Fancy::Object {

public:
    typedef Fancy::ObjPtr<DTDHandler> ptr_t;

    /**
     * Return a new default instance, which does debug logging and nothing else.
     */
    static ptr_t newDefaultInstance();

    /**
     * An entity definition has been parsed.
     *
     * @param ctx  the user data (XML parser context)
     * @param name  the entity name
     * @param type  the entity type
     * @param publicId The public ID of the entity
     * @param systemId The system ID of the entity
     * @param content the entity value (without processing).
     */
    virtual void entityDecl (const char *name,
                     int type,
                     const char *publicId,
                     const char *systemId,
                     char *content);

    /**
     * What to do when a notation declaration has been parsed.
     *
     * @param ctx  the user data (XML parser context)
     * @param name The name of the notation
     * @param publicId The public ID of the entity
     * @param systemId The system ID of the entity
     */
    virtual void notationDecl(const char *name,
                              const char *publicId,
                              const char *systemId);


    /**
     * What to do when an unparsed entity declaration is parsed.
     *
     * @param ctx  the user data (XML parser context)
     * @param name The name of the entity
     * @param publicId The public ID of the entity
     * @param systemId The system ID of the entity
     * @param notationName the name of the notation
     *
     */
    virtual void unparsedEntityDecl(const char *name,
                            const char *publicId,
                            const char *systemId,
                            const char *notationName);

protected:
    DTDHandler();
    virtual ~DTDHandler();
};

}}
#endif /* FANCYSAXDTDHANDLER_H_ */
