/***********************************************************
 * $Id: fancysaxlog.h 1417 2014-12-31 17:45:46Z fancylibs $
 *
 * FancySAX
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSAX_LOG_H
#define FANCYSAX_LOG_H

#include <fancysax.h>
#include <fancylog.h>

// facility masks:
// facility "fancysaxparser"
#define  FANCYSAX_LOG_PARSER          (1<<0)
// facility "fancysaxcontenthandler"
#define  FANCYSAX_LOG_CONTENT_HANDLER (1<<1)
// facility "fancysaxdtdhandler"
#define  FANCYSAX_LOG_DTD_HANDLER     (1<<2)
// facility "fancysaxschema"
#define  FANCYSAX_LOG_SCHEMA          (1<<3)

namespace Fancy {
  namespace SAX {

    extern FANCYSAX_API fancylog_service *log_service;

    // parse for logging cmdline args and filter out recognized options.
    void FANCYSAX_API fancylog_parse_arg (int *argc, char **argv);

    inline void vfancylog (int facility,
                           int priority, const char *fmt, va_list ap)
      {
        va_list aq;
        va_copy(aq,ap);
        ::vfancylog(log_service,facility,priority,fmt,aq);
        va_end(aq);
      }

#ifdef __GNUG__
  inline void fancylog (int facility,
                        int priority, const char *fmt, ...)
    __attribute__((format(printf,3,4)));
    
#endif

    inline void fancylog (int facility,
                          int priority, const char *fmt, ...)
      {
        va_list ap;
        va_start(ap, fmt);
        vfancylog(facility,priority,fmt,ap);
        va_end(ap);
      }
  }
}

#endif // ! FANCYSAX_LOG_H
