/***********************************************************
 * $Id: fancysaxschema.h 1418 2014-12-31 20:18:04Z fancylibs $
 *
 * FancySAX
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSAXSCHEMA_H_
#define FANCYSAXSCHEMA_H_

#include <fancyobject.h>
#include <fancysax.h>

namespace Fancy {

class Channel;

namespace SAX {

class SchemaValidator;

/**
 * A traditional XML schema.
 *
 * A basic usage is the validation of a single document by calling
 * <pre>
 *    Schema::ptr_t schema = Schema::newInstance(schemaUrl);
 *    Reader::ptr_t reader = Reader::newInstance(channel,documentUrl);
 *    SchemaValidator::ptr_t validator = schema->newValidator();
 *    while (reader->nextTag()) ;
 *    std::cout << validator->isSchemaValid() ? "OK" : "Bummer!";
 * </pre>
 */
class FANCYSAX_API Schema: public virtual Fancy::Object {

public:
    typedef Fancy::ObjPtr<Schema> ptr_t;

    /**
     * Read an XML schema from an URL. PLease note, that the I/O
     * functions of libxml are used when resolving resources.
     *
     * An execption is throhwn, if the schema is invalid.
     *
     * @param url The URL to read the schema from.
     * @return A new parsed schema instance.
     */
    static ptr_t newInstance(const std::string &url);

    /**
     * The URL of the schema.
     */
    virtual std::string getUrl() const = 0;

    /**
     * Create a new validator to inject on a @c Reader instance.
     */
    virtual Fancy::ObjPtr<SchemaValidator> newValidator() const = 0;

protected:
    Schema();
    virtual ~Schema();
};

}
}

#endif /* FANCYSAXSCHEMA_H_ */
